==> haskell-crypto-api-0.13.2-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.2
id: crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M
key: crypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
indefinite: False
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
abi: cd8a80bd0fd56278f816522ac1067c79
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-api-0.13.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-api-0.13.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/crypto-api-0.13.2
hs-libraries: HScrypto-api-0.13.2-1dBjbzCEPqW6HZX5e7BC7M
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=9d19b9511d8dce6a0989b1b3b9156e76
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=4764468d99de060aada7572c7b2f4378
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.3
id: crypto-api-0.13.3-KmdbwNmxAqPIjxdyGVlhrI
key: crypto-api-0.13.3-KmdbwNmxAqPIjxdyGVlhrI
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
indefinite: False
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
abi: 45dbc469f4962d5bccc5ea98a3fed84d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-api-0.13.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/crypto-api-0.13.3
hs-libraries: HScrypto-api-0.13.3-KmdbwNmxAqPIjxdyGVlhrI
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=9d19b9511d8dce6a0989b1b3b9156e76
             entropy-0.3.8-459fr1KgYZzBPF08mWgtQU=a6112742140c3bfa625711e5fba8dc1f
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=4764468d99de060aada7572c7b2f4378
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
